1. Prerequisites — Spiker documentation

# 1. Prerequisites

These programs must be installed and callable from the command line:

- Python 3

- Samtools

- bowtie2 (Only needed if your input is fastq file)

# 2. Python Dependencies

- MACS2

- pysam

- pyBigWig

- numpy

- scipy

Note

These packages will be installed automatically if you use pip3.

# 3. Install Spiker

Use pip3 to install spiker from PyPI or github.

    $ pip3 install spiker
    or
    $ pip3 install git+https://github.com/liguowang/spiker.git

# 4. Uninstall

    $ pip3 uninstall spiker

# 5. Upgrade Spiker

    $ pip3 install spiker --upgrade